searchData={"items":[{"type":"module","title":"HyperLLM.Chat","doc":"HyperLLM.Chat is a single interface for interacting with LLM providers.\nThe interface uses the OpenAI chat completion API. https://platform.openai.com/docs/api-reference/chat","ref":"HyperLLM.Chat.html"},{"type":"function","title":"HyperLLM.Chat.completion/3","doc":"","ref":"HyperLLM.Chat.html#completion/3"},{"type":"function","title":"Example - HyperLLM.Chat.completion/3","doc":"iex> HyperLLM.Chat.completion(\"openai/gpt-4o-mini\", [%{role: :user, content: \"Hello\"}], [])\n    {:ok, %{\n      \"id\": \"chatcmpl-123\",\n      \"object\": \"chat.completion\",\n      \"created\": 1677652288,\n      \"model\": \"gpt-4o-mini\",\n      \"system_fingerprint\": \"fp_44709d6fcb\",\n      \"choices\": [{\n        \"index\": 0,\n        \"message\": {\n          \"role\": \"assistant\",\n          \"content\": \"\n\nHello there, how may I assist you today?\",\n        },\n        \"logprobs\": null,\n        \"finish_reason\": \"stop\"\n      }],\n      \"service_tier\": \"default\",\n      \"usage\": {\n        \"prompt_tokens\": 9,\n        \"completion_tokens\": 12,\n        \"total_tokens\": 21,\n        \"completion_tokens_details\": {\n          \"reasoning_tokens\": 0,\n          \"accepted_prediction_tokens\": 0,\n          \"rejected_prediction_tokens\": 0\n        }\n      }\n    }}","ref":"HyperLLM.Chat.html#completion/3-example"},{"type":"module","title":"HyperLLM.Conversation","doc":"HyperLLM.Conversation handles the lifecycle of a conversation, including starting, appending messages, and running the conversation.","ref":"HyperLLM.Conversation.html"},{"type":"module","title":"Example - HyperLLM.Conversation","doc":"A Liveview that sends messages to the chat and updates the chat with the response.\n\n    defmodule ChatLive do\n      use Phoenix.LiveView\n\n      def mount(params, session, socket) do\n        {:ok,\n        socket\n        |> assign(conv: HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\"))}\n      end\n\n      def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n        conv = HyperLLM.Conversation.append(socket.assigns.conv, message)\n\n        send(self(), :chat_completion)\n\n        {:noreply, socket |> assign(conv: conv)}\n      end\n\n      def handle_info(:chat_completion, socket) do\n        with {:ok, conv} <- HyperLLM.Conversation.run(socket.assigns.conv) do\n          {:noreply, socket |> assign(conv: conv)}\n        end\n      end\n    end","ref":"HyperLLM.Conversation.html#module-example"},{"type":"function","title":"HyperLLM.Conversation.append/2","doc":"","ref":"HyperLLM.Conversation.html#append/2"},{"type":"function","title":"HyperLLM.Conversation.append/3","doc":"Append a message to the conversation.","ref":"HyperLLM.Conversation.html#append/3"},{"type":"function","title":"Example - HyperLLM.Conversation.append/3","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\") |> HyperLLM.Conversation.append(:user, \"Hello\")\n    %HyperLLM.Conversation{\n      thread: [%{role: :user, content: \"Hello\"}],\n      model: %HyperLLM.Model{\n        provider: HyperLLM.Provider.OpenAI,\n        model: \"gpt-4o-mini\",\n        config: []\n      }\n    }","ref":"HyperLLM.Conversation.html#append/3-example"},{"type":"type","title":"HyperLLM.Conversation.model_config/0","doc":"","ref":"HyperLLM.Conversation.html#t:model_config/0"},{"type":"function","title":"HyperLLM.Conversation.run/1","doc":"Run the conversation to get a response.","ref":"HyperLLM.Conversation.html#run/1"},{"type":"function","title":"Example - HyperLLM.Conversation.run/1","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\") |> HyperLLM.Conversation.append(:user, \"Hello\") |> HyperLLM.Conversation.run()\n    {:ok, %HyperLLM.Conversation{\n      thread: [%{role: :user, content: \"Hello\"}, %{role: :assistant, content: \"Hello, how can I help you today?\"}],\n      model: \"gpt-4o-mini\"\n    }}","ref":"HyperLLM.Conversation.html#run/1-example"},{"type":"function","title":"HyperLLM.Conversation.run!/1","doc":"","ref":"HyperLLM.Conversation.html#run!/1"},{"type":"function","title":"HyperLLM.Conversation.start/1","doc":"Start a new conversation.","ref":"HyperLLM.Conversation.html#start/1"},{"type":"function","title":"Example - HyperLLM.Conversation.start/1","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\")\n    %HyperLLM.Conversation{\n      thread: [],\n      model: %HyperLLM.Model{\n        provider: HyperLLM.Provider.OpenAI,\n        model: \"gpt-4o-mini\",\n        config: []\n      }\n    }","ref":"HyperLLM.Conversation.html#start/1-example"},{"type":"type","title":"HyperLLM.Conversation.t/0","doc":"","ref":"HyperLLM.Conversation.html#t:t/0"},{"type":"module","title":"HyperLLM.Model","doc":"Determine the provider and model for a given model name.","ref":"HyperLLM.Model.html"},{"type":"type","title":"HyperLLM.Model.config/0","doc":"","ref":"HyperLLM.Model.html#t:config/0"},{"type":"function","title":"HyperLLM.Model.list_providers/0","doc":"List all registered provider modules.\n\nExample:\n\n    iex> HyperLLM.Model.list_providers()\n    [\"anthropic\", \"cloudflare\", \"groq\", \"ollama\", \"openai\"]","ref":"HyperLLM.Model.html#list_providers/0"},{"type":"function","title":"HyperLLM.Model.new!/1","doc":"","ref":"HyperLLM.Model.html#new!/1"},{"type":"function","title":"HyperLLM.Model.parse_model/1","doc":"Parse a model string into a provider and model.\n\nExample:\n\n    iex> HyperLLM.Model.parse_model(\"openai/gpt-4o-mini\")\n    {:ok, {HyperLLM.Provider.OpenAI, \"gpt-4o-mini\"}}\n\n    iex> HyperLLM.Model.parse_model(\"anthropic/claude-3-5-sonnet-20240620\")\n    {:ok, {HyperLLM.Provider.Anthropic, \"claude-3-5-sonnet-20240620\"}}","ref":"HyperLLM.Model.html#parse_model/1"},{"type":"type","title":"HyperLLM.Model.t/0","doc":"","ref":"HyperLLM.Model.html#t:t/0"},{"type":"behaviour","title":"HyperLLM.Provider","doc":"Defines the behaviour that all provider modules must implement.","ref":"HyperLLM.Provider.html"},{"type":"callback","title":"HyperLLM.Provider.completion/2","doc":"","ref":"HyperLLM.Provider.html#c:completion/2"},{"type":"callback","title":"HyperLLM.Provider.model_supported?/1","doc":"","ref":"HyperLLM.Provider.html#c:model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Anthropic","doc":"Provider implementation for Anthropic.\n\nhttps://docs.anthropic.com/en/api/messages","ref":"HyperLLM.Provider.Anthropic.html"},{"type":"module","title":"Configuration: - HyperLLM.Provider.Anthropic","doc":"congfig :hyper_llm, \n      anthropic: [\n        api_key: \"sk-...\",\n        api_version: \"2023-06-01\"\n      ]","ref":"HyperLLM.Provider.Anthropic.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Anthropic.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* claude-3-5-sonnet-latest\n* claude-3-5-sonnet-20240620\n* claude-3-5-haiku-latest\n* claude-3-5-haiku-20241022\n* claude-3-opus-20240229\n* claude-3-sonnet-20240229\n* claude-3-haiku-20240307","ref":"HyperLLM.Provider.Anthropic.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Cloudflare","doc":"Provider implementation for Cloudflare.\n\nUses Cloudflare's [OpenAI compatibility API](https://developers.cloudflare.com/workers-ai/configuration/open-ai-compatibility/) for chat completions.","ref":"HyperLLM.Provider.Cloudflare.html"},{"type":"module","title":"Configuration: - HyperLLM.Provider.Cloudflare","doc":"congfig :hyper_llm, \n      cloudflare: [\n        api_key: \"sk-...\",\n        account_id: \"...\"\n      ]","ref":"HyperLLM.Provider.Cloudflare.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Cloudflare.model_supported?/1","doc":"Checks if the model starts with `@`","ref":"HyperLLM.Provider.Cloudflare.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Groq","doc":"Groq provider.\n\nhttps://console.groq.com/docs/api-reference","ref":"HyperLLM.Provider.Groq.html"},{"type":"function","title":"HyperLLM.Provider.Groq.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* deepseek-r1-distill-llama-70b\n* distil-whisper-large-v3-en\n* gemma2-9b-it\n* llama-3.1-8b-instant\n* llama-3.2-11b-vision-preview\n* llama-3.2-1b-preview\n* llama-3.2-90b-vision-preview\n* llama-3.2-3b-preview\n* llama-3.3-70b-specdec\n* llama-3.3-70b-versatile\n* llama-guard-3-8b\n* llama3-70b-8192\n* llama3-8b-8192\n* mixtral-8x7b-32768\n* whisper-large-v3-turbo\n* whisper-large-v3","ref":"HyperLLM.Provider.Groq.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.OpenAI","doc":"Provider implementation for OpenAI.\n\nhttps://platform.openai.com/docs/api-reference/chat","ref":"HyperLLM.Provider.OpenAI.html"},{"type":"module","title":"Configuration: - HyperLLM.Provider.OpenAI","doc":"congfig :hyper_llm, \n      openai: [\n        api_key: \"sk-...\"\n      ]","ref":"HyperLLM.Provider.OpenAI.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.OpenAI.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* gpt-3.5-turbo\n* gpt-3.5-turbo-0125\n* gpt-3.5-turbo-1106\n* gpt-3.5-turbo-instruct\n* gpt-4-turbo\n* gpt-4-turbo-2024-04-09\n* gpt-4-turbo-preview\n* gpt-4-0125-preview\n* gpt-4-1106-preview\n* gpt-4\n* gpt-4-0613\n* gpt-4-0314\n* gpt-4o-2024-11-20\n* gpt-4o-2024-08-06\n* gpt-4o-2024-05-13\n* gpt-4o-mini\n* gpt-4o-mini-2024-07-18\n* o1\n* o1-2024-12-17\n* o1-mini\n* o1-mini-2024-09-12\n* o1-preview\n* o1-preview-2024-09-12\n* o3-mini\n* o3-mini-2025-01-31","ref":"HyperLLM.Provider.OpenAI.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Providers.Ollama","doc":"Provider implementation for Ollama.\n\nhttps://github.com/ollama/ollama/blob/main/docs/api.md#generate-a-chat-completion","ref":"HyperLLM.Providers.Ollama.html"},{"type":"module","title":"Configuration: - HyperLLM.Providers.Ollama","doc":"config :hyper_llm, \n      ollama: [\n        api_url: \"http://localhost:11434\",\n        api_key: \"ollama\"\n      ]","ref":"HyperLLM.Providers.Ollama.html#module-configuration"},{"type":"function","title":"HyperLLM.Providers.Ollama.model_supported?/1","doc":"Ollama supports all models.","ref":"HyperLLM.Providers.Ollama.html#model_supported?/1"},{"type":"behaviour","title":"HyperLLM.Tool","doc":"Defines the behaviour that all workflow tool modules must implement.\n\nEach tool module must implement the `call/1` callback, which takes a keyword list\nof inputs and returns a tuple containing a result atom and output keyword list.","ref":"HyperLLM.Tool.html"},{"type":"callback","title":"HyperLLM.Tool.call/1","doc":"Executes the tool with the given input values.","ref":"HyperLLM.Tool.html#c:call/1"},{"type":"callback","title":"Parameters - HyperLLM.Tool.call/1","doc":"* `input` - A keyword list containing the tool-specific input values","ref":"HyperLLM.Tool.html#c:call/1-parameters"},{"type":"callback","title":"Returns - HyperLLM.Tool.call/1","doc":"* `{result, output}` - A tuple containing:\n    * `result` - An atom indicating the result of the tool execution (e.g., :ok, :error, :high, :low)\n    * `output` - A keyword list containing the tool's output values","ref":"HyperLLM.Tool.html#c:call/1-returns"},{"type":"extras","title":"HyperLLM","doc":"# HyperLLM\n\n[![CI](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml/badge.svg)](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml)\n[![License](https://img.shields.io/hexpm/l/hyper_llm.svg)](https://github.com/cgarvis/hyper_llm/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/hyper_llm.svg)](https://hex.pm/packages/hyper_llm)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/hyper_llm)\n\nCall all LLM APIs using the OpenAI format.","ref":"readme.html"},{"type":"extras","title":"Installation - HyperLLM","doc":"Add `hyper_llm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hyper_llm, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configurations - HyperLLM","doc":"```elixir\nconfig :hyper_llm,\n  openai: [\n    api_key: \"sk-...\"\n  ],\n  anthropic: [\n    api_key: \"sk-...\"\n  ]\n```","ref":"readme.html#configurations"},{"type":"extras","title":"Usage - HyperLLM","doc":"```elixir\nHyperLLM.Chat.start(model: \"openai/gpt-4o-mini\")\n|> HyperLLM.Chat.append(:developer, \"You are a helpful assistant.\")\n|> HyperLLM.Chat.append(:user, \"Spell \\\"strawberry\\\"\")\n|> HyperLLM.Chat.completion()\n#=> {:ok, \"Strawberry. 🍓\"}\n```\n\nIf you are using Phoenix, you can use the `HyperLLM.Chat` module in your LiveView.\n\n```elixir\ndefmodule ChatLive do\n  use Phoenix.LiveView\n\n  def render(assigns) do\n    ~H\"\"\"\n     \n       \n        <%= for message <- @chat.messages do %>\n           <%= message.role %> \n           <%= message.content %> \n        <% end %>\n       \n     \n    \"\"\"\n  end\n\n  def mount(params, session, socket) do\n    {:ok,\n    socket\n    |> assign(chat: HyperLLM.Chat.start(model: \"gpt-4o-mini\"))}\n  end\n\n  def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n    chat = HyperLLM.Chat.append(socket.assigns.chat, message)\n\n    send(self(), :chat_completion)\n    \n    {:noreply, socket |> assign(chat: chat)}\n  end\n\n  def handle_info(:chat_completion, socket) do\n    with {:ok, response} <- HyperLLM.Chat.completion(socket.assigns.chat) do\n      chat = HyperLLM.Chat.append(socket.assigns.chat, :assistant, response)\n      {:noreply, socket |> assign(chat: chat)}\n    end\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Providers - HyperLLM","doc":"| Provider           | Completion | Streaming | \n| ------------------ | ---------- | --------- |\n| Anthropic          | ✅         | ❌        |\n| Cloudflare         | ✅         | ❌        |\n| Groq               | ✅         | ❌        |\n| Ollama             | ✅         | ❌        |\n| OpenAI             | ✅         | ❌        |\n| Azure              | ❌         | ❌        |\n| AWS SageMaker      | ❌         | ❌        |\n| AWS Bedrock        | ❌         | ❌        |\n| Cohere             | ❌         | ❌        |\n| DeepSeek           | ❌         | ❌        |\n| Empower            | ❌         | ❌        |\n| Google - Vertex AI | ❌         | ❌        |\n| Google - Palm      | ❌         | ❌        |\n| Google AI Studio   | ❌         | ❌        |\n| Hugging Face       | ❌         | ❌        |\n| Mistral AI         | ❌         | ❌        |\n| Perplexity         | ❌         | ❌        |\n| Replicate          | ❌         | ❌        |\n| TogetherAI         | ❌         | ❌        |\n| Vertex AI          | ❌         | ❌        |","ref":"readme.html#providers"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}